@@ -293,6 +293,11 @@ def getSubmitFile(filename, computer, typeCalculation, inpDict):
             
             f.write('#SBATCH --time={:02d}:{:02d}:{:02d}\n'.format(hours,minutes,seconds))
 
+        if k == 'use':
+
+            for item in v:
+                f.write('module use {}\n'.format(item))
+
         if k == 'modules':
 
             for item in v:
